@@ -1,19 +1,33 @@
 /*
  * This file is part of LibKGAPI library
  *
- * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#pragma once
+#ifndef LIBKGAPI2_CALENDAR_H
+#define LIBKGAPI2_CALENDAR_H
 
-#include "kgapicalendar_export.h"
 #include "object.h"
 #include "types.h"
+#include "kgapicalendar_export.h"
 
 #include <QColor>
-#include <QScopedPointer>
 
 namespace KGAPI2
 {
@@ -24,9 +38,10 @@ namespace KGAPI2
  * @author Daniel Vrátil <dvratil@redhat.com>
  * @since 0.1
  */
-class KGAPICALENDAR_EXPORT Calendar : public KGAPI2::Object
+class KGAPICALENDAR_EXPORT Calendar: public KGAPI2::Object
 {
-public:
+
+  public:
     /**
      * @brief Constructor
      */
@@ -74,7 +89,7 @@ public:
     QString details() const;
 
     /**
-     * @brief Sets detailed description of a calendar.
+     * @brief Sets detailed description of a calenar.
      *
      * @param details
      */
@@ -131,7 +146,7 @@ public:
     void addDefaultReminer(const ReminderPtr &reminder);
 
     /**
-     * @brief Returns default reminders for all events in the calendar.
+     * @brief Returns defalut reminders for all events in the calendar.
      */
     RemindersList defaultReminders() const;
 
@@ -143,7 +158,7 @@ public:
     QColor backgroundColor() const;
 
     /**
-     * @brief Sets calendar background color.
+     * @brief Sets calendar backgrond color.
      *
      * @param color
      *
@@ -167,9 +182,12 @@ public:
      */
     void setForegroundColor(const QColor &color);
 
-protected:
+  protected:
     class Private;
-    QScopedPointer<Private> const d;
+    Private * const d;
+
 };
 
 } // namespace KGAPI2
+
+#endif // LIBKGAPI2_CALENDAR_H
